Clazz.declarePackage("J.shapebio");
Clazz.load(["J.shapebio.BioShapeCollection"], "J.shapebio.Ribbons", null, function(){
var c$ = Clazz.declareType(J.shapebio, "Ribbons", J.shapebio.BioShapeCollection);
});
;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
